summaryrefslogtreecommitdiffstats
path: root/lib/kformula/basicelement.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit7c71ab86d1f7e387fc3df63b48df07231f111862 (patch)
tree30ba2d2f840ff5fd458b6113e9c3f2e8a71d510d /lib/kformula/basicelement.h
parentafbfdc507bfaafc8824a9808311d57a9ece87510 (diff)
downloadkoffice-7c71ab86d1f7e387fc3df63b48df07231f111862.tar.gz
koffice-7c71ab86d1f7e387fc3df63b48df07231f111862.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kformula/basicelement.h')
-rw-r--r--lib/kformula/basicelement.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/kformula/basicelement.h b/lib/kformula/basicelement.h
index d373fc6c..025dfbc6 100644
--- a/lib/kformula/basicelement.h
+++ b/lib/kformula/basicelement.h
@@ -141,7 +141,7 @@ public:
* is allowed to set the cursor.
*/
virtual BasicElement* goToPos( FormulaCursor*, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
/**
* Returns our position inside the widget.
@@ -158,7 +158,7 @@ public:
/**
* Calculates our width and height and
- * our tqchildren's tqparentPosition.
+ * our tqchildren's parentPosition.
*/
virtual void calcSizes( const ContextStyle& context,
ContextStyle::TextStyle tstyle,
@@ -167,15 +167,15 @@ public:
/**
* Draws the whole element including its tqchildren.
* The `tqparentOrigin' is the point this element's tqparent starts.
* We can use our tqparentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& context,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& tqparentOrigin ) = 0;
+ const LuPixelPoint& parentOrigin ) = 0;
/**
@@ -167,15 +167,15 @@ public:
/**
* Draws the whole element including its tqchildren.
- * The `tqparentOrigin' is the point this element's tqparent starts.
- * We can use our tqparentPosition to get our own origin then.
+ * The `parentOrigin' is the point this element's tqparent starts.
+ * We can use our parentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,